==> typescript-config-1.0.7.tgz: package/README.md <==
<!--
MIT License

Copyright (c) 2021 Bootcamp-Project contributors <contributors@bootcamp-project.com>

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
-->
<a href="https://bootcamp-project.com/" target="_blank"><img src="https://bootcamp-project.com/tbcp.svg" align="right" height="200" /></a>

# Ready-to-use TypeScript Configuration

## with Security-first and ESLint settings by default

<img src="https://img.shields.io/npm/v/@bootcamp-project/typescript-config?style=for-the-badge">
<img src="https://img.shields.io/npm/types/@bootcamp-project/typescript-config?style=for-the-badge">
<img src="https://img.shields.io/librariesio/release/npm/@bootcamp-project/typescript-config?style=for-the-badge">
<img src="https://img.shields.io/gitlab/pipeline-status/the-bootcamp-project/configurations/typescript?branch=main&style=for-the-badge">
<img src="https://img.shields.io/npm/dm/@bootcamp-project/typescript-config?style=for-the-badge">
<img src="https://img.shields.io/badge/License-MIT-lightgrey?style=for-the-badge" />
<img src="https://img.shields.io/npm/collaborators/@bootcamp-project/typescript-config?style=for-the-badge">
<img src="https://img.shields.io/badge/Bootcamp-Project-blue?style=for-the-badge" />

## 🦄 About 🦄

> Description

**Project Links**

- [Homepage][Repo_Homepage]
- [Repository][Repo_URL]
- [Documentation][Repo_Docs]
- [Issues][Repo_Issues]

**Minimum Viable Product**: *What is what we want?*

- **What are the goals?**
  - [ ] Goal #1
  - [ ] Goal #2
  - [ ] Goal #3
- **Sense** *(Why do these goals exist?)*
  - [ ] Explanation #1
  - [ ] Explanation #2
  - [ ] Explanation #3
- **Purpose** *(What should be done with it?)*
  - [ ] Use Case #1
  - [ ] Use Case #2
  - [ ] Use Case #3

## 🚀 Getting Started 🚀

### 💪 Installation 💪

```bash
npm install --safe-dev typescript @bootcamp-project/typescript-config
# or
yarn add --dev typescript @bootcamp-project/typescript-config
```

## 🤩 Usage 🤩

**TBCP Best Practice**

> See [TBCP default TypeScript settings][Repo_Config]

```json
// tsconfig.json
{
	"extends": "@bootcamp-project/typescript-config/src/tsconfig.json",
	"include": [
		"src/**/*"
	],
	"exclude": [
		"node_modules/*"
	],
	"compilerOptions": {
		"target": "es5", /* Set the JavaScript language version for emitted JavaScript and include compatible library declarations. */
		"removeComments": false, /* Disable emitting comments. */
		"module": "commonjs", /* Specify what module code is generated. */
		"outDir": "./dist", /* Specify an output folder for all emitted files. */
		"declarationDir": "./dist/@types", /* Specify the output directory for generated declaration files. */
		"declaration": true, /* Generates corresponding '.d.ts' file. */
		"declarationMap": false, /* Generates a sourcemap for each corresponding '.d.ts' file. */
		"sourceMap": false, /* Create source map files for emitted JavaScript files. */
		"inlineSourceMap": true, /* Include sourcemap files inside the emitted JavaScript. */
		"inlineSources": true, /* Include source code in the sourcemaps inside the emitted JavaScript. */
	}
}
```

### 🤓 Static Analysis 🤓

```js
// .eslintrc.js
'use strict';

const ESLintConfig = require('@bootcamp-project/typescript-config').ESLintTypeScript
module.exports = ESLintConfig
```

**If you want more...**

```js
// .eslintrc.js
'use strict';

const ESLintConfig = require('@bootcamp-project/typescript-config').ESLintTypeScript
module.exports = {
  ...ESLintConfig, // Takes the TBCP base settings
  // ...
  // add your own ESLint settings here
  // ...
}
```

## ⭐️ Features ⭐️

- Latest preinstalled **Dependencies** by default
- [**Security-first production ready configuration**][TBCP_Configurations] by default
- [Extensive configuration **documentation**][Repo_Docs]

### 😎 Built With 😎

<table>
<tr>
<td><a href="https://typescriptlang.org/" target="_blank"><img src="https://cdr.bootcamp-project.com/logos/programming/typescript.svg" alt="TypeScript" width="200"/></a></td>
<td><a href="https://svelte.dev/" target="_blank"><img src="https://cdr.bootcamp-project.com/logos/programming/svelte.svg" alt="Svelte" width="200"/></a></td>
<td><a href="https://eslint.org/" target="_blank"><img src="https://cdr.bootcamp-project.com/logos/programming/eslint.svg" alt="eslint" width="200"/></a></td>
<td><a href="https://jestjs.io/" target="_blank"><img src="https://cdr.bootcamp-project.com/logos/programming/jest.svg" alt="jest" width="200"/></a></td>
<td><a href="https://rollupjs.org/" target="_blank"><img src="https://cdr.bootcamp-project.com/logos/programming/rollup.svg" alt="Rollup" width="200"/></a></td>
<td><a href="https://webpack.js.org/" target="_blank"><img src="https://cdr.bootcamp-project.com/logos/programming/webpack.svg" alt="Webpack" width="200"/></a></td>
<td><a href="https://bootcamp-project.com/" target="_blank"><img src="https://bootcamp-project.com/tbcp.svg" alt="tbcp" width="200"/></a></td>
</tr>
</table>

### 🏆 Acknowledgements 🏆

Thanks for these awesome resources that were used during the development of the **Bootcamp: TypeScript Configuration**:

- [TypeScript](https://www.typescriptlang.org/)

## 📑 Changelog 📑

See [CHANGELOG](CHANGELOG) for more information.

## 📋 Roadmap 📋

See the [open issues][Repo_Issues] for a list of proposed features (and known issues).

## 🤝 Contribute 🤝

Contributions are what make the open source community such an amazing place to be learn, inspire, and create. Any contributions you make are **greatly appreciated**.

Please read the [contribution guidelines][TBCP_Contribution] first.

1. Fork the Project
2. Create your Feature Branch (`git checkout -b feature/AmazingFeature`)
3. Commit your Changes (`git commit -m 'Add some AmazingFeature'`)
4. Push to the Branch (`git push origin feature/AmazingFeature`)
5. Open a Pull Request

## 📜 License 📜

See [LICENSE](LICENSE) for more information.

## 💌 Contact 💌

[Bootcamp contributors][TBCP_Homepage] - `contributors` @ `bootcamp-project` .com

<!-- ---------------------------------------------------------------------------------------------------------------------------------- -->
<!-- ---------------------------------------------------------------------------------------------------------------------------------- -->
<!-- ---------------------------------------------------------------------------------------------------------------------------------- -->

[Repo_Homepage]: https://configurations.bootcamp-project.com/#/transcompiler/typescript
[Repo_URL]: https://gitlab.com/the-bootcamp-project/configurations/typescript
[Repo_Docs]: https://configurations.bootcamp-project.com/#/transcompiler/typescript
[Repo_Config]: https://configurations.bootcamp-project.com/#/transcompiler/typescript_config
[Repo_Issues]: https://gitlab.com/the-bootcamp-project/configurations/typescript/-/issues
[TBCP_Configurations]: https://configurations.bootcamp-project.com
[TBCP_Contribution]: https://bootcamp-project.com/#code_of_conduct
[TBCP_Homepage]: https://bootcamp-project.com

==> typescript-config-1.1.1.tgz: package/README.md <==
<!--
MIT License

Copyright (c) 2021 Bootcamp-Project contributors <contributors@bootcamp-project.com>

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
-->
<a href="https://bootcamp-project.com/" target="_blank"><img src="https://bootcamp-project.com/tbcp.svg" align="right" height="200" /></a>

# Ready-to-use TypeScript Configuration

## with Security-first and ESLint settings by default

<img src="https://img.shields.io/npm/v/@bootcamp-project/typescript-config?style=for-the-badge">
<img src="https://img.shields.io/npm/types/@bootcamp-project/typescript-config?style=for-the-badge">
<img src="https://img.shields.io/librariesio/release/npm/@bootcamp-project/typescript-config?style=for-the-badge">
<img src="https://img.shields.io/gitlab/pipeline-status/the-bootcamp-project/configurations/typescript?branch=main&style=for-the-badge">
<img src="https://img.shields.io/npm/dm/@bootcamp-project/typescript-config?style=for-the-badge">
<img src="https://img.shields.io/badge/License-MIT-lightgrey?style=for-the-badge" />
<img src="https://img.shields.io/npm/collaborators/@bootcamp-project/typescript-config?style=for-the-badge">
<img src="https://img.shields.io/badge/Bootcamp-Project-blue?style=for-the-badge" />

## 🦄 About 🦄

> Description

**Project Links**

- [Homepage][Repo_Homepage]
- [Repository][Repo_URL]
- [Documentation][Repo_Docs]
- [Issues][Repo_Issues]

**Minimum Viable Product**: *What is what we want?*

- **What are the goals?**
  - [ ] Goal #1
  - [ ] Goal #2
  - [ ] Goal #3
- **Sense** *(Why do these goals exist?)*
  - [ ] Explanation #1
  - [ ] Explanation #2
  - [ ] Explanation #3
- **Purpose** *(What should be done with it?)*
  - [ ] Use Case #1
  - [ ] Use Case #2
  - [ ] Use Case #3

## 🚀 Getting Started 🚀

### 💪 Installation 💪

```bash
npm install --safe-dev typescript @bootcamp-project/typescript-config
# or
yarn add --dev typescript @bootcamp-project/typescript-config
```

## 🤩 Usage 🤩

> See [TBCP TypeScript settings][Repo_Config]

```js
// .eslintrc.js
'use strict';

const ESLintConfig = require('@bootcamp-project/typescript-config').ESLintTypeScript
module.exports = ESLintConfig
```

**If you want more...**

```js
// .eslintrc.js
'use strict';

const ESLintConfig = require('@bootcamp-project/typescript-config').ESLintTypeScript
module.exports = {
  ...ESLintConfig, // Takes the TBCP base settings
  // ...
  // add your own ESLint settings here
  // ...
}
```

## ⭐️ Features ⭐️

- Latest preinstalled **Dependencies** by default
- [**Security-first production ready configuration**][TBCP_Configurations] by default
- [Extensive configuration **documentation**][Repo_Docs]

### 😎 Built With 😎

<table>
<tr>
<td><a href="https://typescriptlang.org/" target="_blank"><img src="https://cdr.bootcamp-project.com/logos/programming/typescript.svg" alt="TypeScript" width="200"/></a></td>
<td><a href="https://eslint.org/" target="_blank"><img src="https://cdr.bootcamp-project.com/logos/programming/eslint.svg" alt="eslint" width="200"/></a></td>
<td><a href="https://webpack.js.org/" target="_blank"><img src="https://cdr.bootcamp-project.com/logos/programming/webpack.svg" alt="Webpack" width="200"/></a></td>
<td><a href="https://bootcamp-project.com/" target="_blank"><img src="https://bootcamp-project.com/tbcp.svg" alt="tbcp" width="200"/></a></td>
</tr>
</table>

### 🏆 Acknowledgements 🏆

Thanks for these awesome resources that were used during the development of the **Bootcamp: TypeScript Configuration**:

- [TypeScript](https://www.typescriptlang.org/)
- [RTFM.page: TypeScript](https://dev.rtfm.page/#/working_with/javascript/typescript)

## 📑 Changelog 📑

See [CHANGELOG](CHANGELOG) for more information.

## 📋 Roadmap 📋

See the [open issues][Repo_Issues] for a list of proposed features (and known issues).

## 🤝 Contribute 🤝

Contributions are what make the open source community such an amazing place to be learn, inspire, and create. Any contributions you make are **greatly appreciated**.

Please read the [contribution guidelines][TBCP_Contribution] first.

0. [Give us a star][Repo_Stars], it's really important! 😅
1. Fork the Project: (`git clone https://gitlab.com/the-bootcamp-project/configurations/typescript.git`)
2. Create your Feature Branch (`git checkout -b feature/AmazingFeature`)
3. Commit your Changes (`git commit -m 'Add some AmazingFeature'`)
4. Push to the Branch (`git push origin feature/AmazingFeature`)
5. Open a Pull Request

## 📜 License 📜

See [LICENSE](LICENSE) for more information.

## 💌 Contact 💌

[Bootcamp contributors][TBCP_Homepage] - `contributors` @ `bootcamp-project` .com

<!-- ---------------------------------------------------------------------------------------------------------------------------------- -->
<!-- ---------------------------------------------------------------------------------------------------------------------------------- -->
<!-- ---------------------------------------------------------------------------------------------------------------------------------- -->

[Repo_Homepage]: https://configurations.bootcamp-project.com/#/transcompiler/typescript
[Repo_URL]: https://gitlab.com/the-bootcamp-project/configurations/typescript
[Repo_Docs]: https://configurations.bootcamp-project.com/#/transcompiler/typescript
[Repo_Config]: https://configurations.bootcamp-project.com/#/transcompiler/typescript_config
[Repo_Issues]: https://gitlab.com/the-bootcamp-project/configurations/typescript/-/issues
[Repo_Forks]: https://gitlab.com/the-bootcamp-project/configurations/typescript/-/forks
[Repo_Stars]: https://gitlab.com/the-bootcamp-project/configurations/typescript/-/starrers
[TBCP_Configurations]: https://configurations.bootcamp-project.com
[TBCP_Contribution]: https://bootcamp-project.com/#code_of_conduct
[TBCP_Homepage]: https://bootcamp-project.com
